@@ -340,6 +340,29 @@ class DataSource:
         """
         raise NotImplementedError()
 
+    def get_all_locations(
+        self, t0_datetimes_utc: pd.DatetimeIndex
+    ) -> Tuple[pd.DatetimeIndex, List[Number], List[Number]]:
+        """Find all valid geographical locations for each t0_datetime.
+
+        Should be overridden by DataSources which may be used to define the locations.
+
+        Returns:  all_t0_datetimes_utc, x_locations, y_locations.
+            For each single t0_datetime, there are all possible locations.
+            Each return has length len(t0_datetimes_utc) * number_of_location
+            Locations are in OSGB coordinates.
+        """
+        raise NotImplementedError()
+
+    def get_number_locations(self) -> int:
+        """
+        Get the number of locations of a data source
+
+        For GSP, this is the number of GSP
+        For PV, this is the number of PV locations
+        """
+        raise NotImplementedError()
+
     # ****************** METHODS THAT MUST BE OVERRIDDEN **********************
     # TODO: Issue #319: Standardise parameter names.
     def _get_time_slice(self, t0_dt: pd.Timestamp):
