@@ -69,6 +69,18 @@ class DataSourceOutput(PydanticXArrayDataSet):
             logger.error(message)
             raise Exception(message)
 
+    def check_nan_and_fill_warning(self, data: xr.Dataset, variable_name: str = None) -> xr.Dataset:
+        """Check that all values are non NaNs and not infinite"""
+
+        if np.isnan(data).any():
+            message = f"Some {self.__class__.__name__} data values are NaNs"
+            if variable_name is not None:
+                message += f" ({variable_name})"
+            logger.warning(message)
+            data = data.fillna(0)
+
+        return data
+
     def check_dataset_greater_than_or_equal_to(
         self, data: xr.Dataset, min_value: int, variable_name: str = None
     ):
